Changelog
=========


0.5.1 (2016-11-07)
------------------

- Fix manifest.
- Fix CSS.
- Remove extra colon after labels which is now added via CSS.


0.5 (2016-10-17)
----------------

- Modify the TitleViewlet to create a custom title for ListingDetail views.
- Override the DublinCore viewlet to create custom metatags for ListingDetail and DevelopmentDetail views.
- Bugfix: Developments on second page of a collection (and beyond) cannot be shown.
- Bugfix: Allow print-listing view on listings within a development.
- Check for valid development listings.
- Remove Google Maps API from portal_javascripts.
- Google Maps now uses configured API key.


0.4 (2016-05-20)
----------------

- Add CSS classes to listing summary fields.
- Only show development detail page if development is available in collection.
- Show interior area and living area in listing summary, if available.


0.3 (2016-02-18)
----------------

- Fix canonical links for development detail pages to point to themselves rather than the development collection.


0.2.8 (2016-02-10)
------------------

- Added option switch between short and long urls for development collections.
- Fix robot tests.
- Fix code-analysis errors and warnings.


0.2.7 (2015-08-29)
------------------

- *bugfix:* Development contact form crashed on ascii characters in name or message


0.2.6 (2015-08-11)
------------------

- improved styling for Development header captions


0.2.5 (2015-07-07)
------------------

- No changes yet.


0.2.4 (2015-06-11)
------------------

- prevent pagination error of plone.batching (1.0.4) in *development details*


0.2.3 (2015-06-11)
------------------

- **Develoments Details:** add hover *"title"* for development icons


0.2.2 (2015-06-02)
------------------

- Develoments Summary: get custom css class for prettier results


0.2.1 (2015-06-01)
------------------

- improve Developments Summary View
- improve Developments Detail View: no prettyPhoto Iframe links for phase-listings


0.2 (2015-05-13)
----------------

- Added Developer MLS Embedding.
- Added additional fields to customize the contact information (agency and agent).
- I18N updates.


0.1 (2014-07-15)
----------------

- Initial release.
- Added 'Featured Listings' content type and viewlet.
